@@ -19,7 +19,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: CamelWrapper.java 20334 2010-09-16 16:14:03Z alitokmen $
+ * $Id: CamelWrapper.java 21303 2011-05-24 11:36:38Z ardaaydin $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jonas.camel.wrapper;
@@ -36,9 +36,11 @@ import org.apache.camel.CamelContext;
 import org.apache.camel.Component;
 import org.apache.camel.ProducerTemplate;
 import org.apache.camel.builder.RouteBuilder;
+import org.apache.camel.component.ref.RefComponent;
+import org.apache.camel.core.osgi.OsgiDefaultCamelContext;
 import org.apache.camel.impl.DefaultCamelContext;
 import org.apache.camel.model.RouteDefinition;
-import org.apache.camel.osgi.CamelContextFactory;
+import org.osgi.framework.BundleContext;
 import org.ow2.jonas.camel.registry.osgi.OSGiRegistry;
 import org.ow2.jonas.camel.registry.xml.RegistryWrapper;
 import org.ow2.util.log.Log;
@@ -74,15 +76,17 @@ public class CamelWrapper implements ICamelWrapper {
     /**
      * Constructor, creates a new Camel context.
      * 
-     * @param factory Camel context factory to use.
+     * @param bundleContext Bundle context to use.
      */
-    public CamelWrapper(final CamelContextFactory factory) {
-        final DefaultCamelContext ctx = factory.createContext();
-        OSGiRegistry osgiRegistry = new OSGiRegistry(factory.getBundleContext());
+    public CamelWrapper(final BundleContext bundleContext) {
+        final DefaultCamelContext ctx = new OsgiDefaultCamelContext(bundleContext);
+        OSGiRegistry osgiRegistry = new OSGiRegistry(bundleContext);
         ctx.setRegistry(osgiRegistry);
         // for compatibility with previous registry only, routes beginning
         // with registry: should be associate with Camel's RefComponent
-        ctx.addComponent("registry", new RefComponentWithCreateEndpointPatch());
+        ctx.addComponent("registry", new RefComponent());
+        // set context name with bundle symbolic name
+        ctx.setName(bundleContext.getBundle().getSymbolicName());
         // create the wrapper
         this.registryWrapper = new RegistryWrapper();
         // Create the registry and assign the context to it.
